@@ -13,9 +13,9 @@ from fideslog.sdk.python.event import AnalyticsEvent
 from fideslog.sdk.python.exceptions import AnalyticsException
 from fideslog.sdk.python.utils import OPT_OUT_COPY
 
-from fidesctl.core.config.utils import get_config_from_file, update_config_file
-from fidesctl.core.utils import echo_red, check_response
 from fidesctl.core import api as _api
+from fidesctl.core.config.utils import get_config_from_file, update_config_file
+from fidesctl.core.utils import check_response, echo_green, echo_red
 
 
 def check_server(cli_version: str, server_url: str) -> None:
@@ -31,11 +31,14 @@ def check_server(cli_version: str, server_url: str) -> None:
         raise SystemExit(1)
 
     server_version = health_response.json()["version"]
-    if str(server_version) != str(cli_version):
+    if str(server_version) == str(cli_version):
+        echo_green(
+            "Server is reachable and the client/server application versions match."
+        )
+    else:
         echo_red(
             f"Mismatched versions!\nServer Version: {server_version}\nCLI Version: {cli_version}"
         )
-        raise SystemExit(1)
 
 
 def pretty_echo(dict_object: Dict, color: str = "white") -> None:
